==> eorzea-time-1.0.0.tgz: package/lib/eorzea-time.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global.EorzeaTime = factory());
}(this, function () { 'use strict';

  var babelHelpers = {};

  babelHelpers.classCallCheck = function (instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  };

  babelHelpers.createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  babelHelpers;

  var repeat = String.prototype.repeat || function () {
    var count = arguments.length <= 0 || arguments[0] === undefined ? 0 : arguments[0];

    var string = String(this);
    var n = +count;
    var result = '';
    while (n--) {
      result += string;
    }
    return result;
  };

  var padStart = String.prototype.padStart || function (maxLength) {
    var fillString = arguments.length <= 1 || arguments[1] === undefined ? ' ' : arguments[1];

    var string = String(this);
    var stringLength = string.length;
    if (maxLength <= stringLength) {
      return string;
    }
    var fillStringLength = String(fillString).length;
    var fillLength = maxLength - stringLength;
    var filler = repeat.call(fillString, Math.ceil(fillLength / fillStringLength));
    return filler + string;
  };

  var THREE_MINUTES = 3 /* minutes */ * 60 /* seconds */ * 1000 /* ms */;
  var privateDateProperty = typeof Symbol !== 'function' ? Symbol('privateDateProperty') : '_privateDateProperty';

  function computeEorzeaDate(date) {
    var eorzeaTime = new Date();
    var unixTime = Math.floor(date.getTime() * 1440 / 70 - THREE_MINUTES);
    eorzeaTime.setTime(unixTime);
    return eorzeaTime;
  }

  var EorzeaTime = function () {
    function EorzeaTime() {
      var date = arguments.length <= 0 || arguments[0] === undefined ? new Date() : arguments[0];
      babelHelpers.classCallCheck(this, EorzeaTime);

      this[privateDateProperty] = computeEorzeaDate(date);
    }

    babelHelpers.createClass(EorzeaTime, [{
      key: 'getHours',
      value: function getHours() {
        return this[privateDateProperty].getUTCHours();
      }
    }, {
      key: 'getMinutes',
      value: function getMinutes() {
        return this[privateDateProperty].getUTCMinutes();
      }
    }, {
      key: 'getSeconds',
      value: function getSeconds() {
        return this[privateDateProperty].getUTCSeconds();
      }
    }, {
      key: 'toString',
      value: function toString() {
        return [padStart.call(this.getHours(), 2, 0), padStart.call(this.getMinutes(), 2, 0), padStart.call(this.getSeconds(), 2, 0)].join(':');
      }
    }, {
      key: 'toJSON',
      value: function toJSON() {
        return toString();
      }
    }]);
    return EorzeaTime;
  }();

  return EorzeaTime;

}));

==> eorzea-time-1.0.1.tgz: package/lib/eorzea-time.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global.EorzeaTime = factory());
}(this, function () { 'use strict';

  var babelHelpers = {};

  babelHelpers.classCallCheck = function (instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  };

  babelHelpers.createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  babelHelpers;

  var repeat = String.prototype.repeat || function repeat() {
    var count = arguments.length <= 0 || arguments[0] === undefined ? 0 : arguments[0];

    /* eslint-disable no-invalid-this */
    var string = String(this);
    var n = +count;
    var result = '';
    while (n--) {
      result += string;
    }
    return result;
  };

  var padStart = String.prototype.padStart || function padStart(maxLength) {
    var fillString = arguments.length <= 1 || arguments[1] === undefined ? ' ' : arguments[1];

    /* eslint-disable no-invalid-this */
    var string = String(this);
    var stringLength = string.length;
    if (maxLength <= stringLength) {
      return string;
    }
    var fillStringLength = String(fillString).length;
    var fillLength = maxLength - stringLength;
    var filler = repeat.call(fillString, Math.ceil(fillLength / fillStringLength));
    return filler + string;
  };

  var THREE_MINUTES = 3 * 60 * 1000;
  var privateDateProperty = typeof Symbol === 'function' ? Symbol('privateDateProperty') : '_privateDateProperty';

  function computeEorzeaDate(date) {
    var eorzeaTime = new Date();
    var unixTime = Math.floor(date.getTime() * 1440 / 70 - THREE_MINUTES);
    eorzeaTime.setTime(unixTime);
    return eorzeaTime;
  }

  var EorzeaTime = function () {
    function EorzeaTime() {
      var date = arguments.length <= 0 || arguments[0] === undefined ? new Date() : arguments[0];
      babelHelpers.classCallCheck(this, EorzeaTime);

      this[privateDateProperty] = computeEorzeaDate(date);
    }

    babelHelpers.createClass(EorzeaTime, [{
      key: 'getHours',
      value: function getHours() {
        return this[privateDateProperty].getUTCHours();
      }
    }, {
      key: 'getMinutes',
      value: function getMinutes() {
        return this[privateDateProperty].getUTCMinutes();
      }
    }, {
      key: 'getSeconds',
      value: function getSeconds() {
        return this[privateDateProperty].getUTCSeconds();
      }
    }, {
      key: 'toString',
      value: function toString() {
        return [padStart.call(this.getHours(), 2, 0), padStart.call(this.getMinutes(), 2, 0), padStart.call(this.getSeconds(), 2, 0)].join(':');
      }
    }, {
      key: 'toJSON',
      value: function toJSON() {
        return toString();
      }
    }]);
    return EorzeaTime;
  }();

  return EorzeaTime;

}));
